import { Engine, EngineResult, Rule } from 'json-rules-engine';
import { GlobalRules, S3GetInput } from '../types/UtilTypes';
import { S3 } from '../libs/s3';
import { Logger } from '@aws-lambda-powertools/logger';

const logger = new Logger({ serviceName: 'ApplyRules' });

export async function applyRules(inputData: GlobalRules): Promise<any[]> {
  try {
    const bucketName = 'json-rules-engine';

    const param: S3GetInput = {
      Bucket: bucketName,
      Key: inputData.nameRule,
    };

    const s3Data = await S3.getObject(param);
    const jsonRules: Rule[] = JSON.parse(s3Data).decisions;

    const engine = new Engine();
    jsonRules.forEach((rule) => {
      engine.addRule(rule);
    });

    const results: EngineResult = await engine.run(inputData.data);
    return [results];
  } catch (error) {
    logger.error(error);
    throw error;
  }
}
